Page
Library
Module
Module type
Parameter
Class
Class type
Fast_bitvectorSourceMaximum length of any bitvector. Depends on host architecture.
module type Ops := sig ... enddst specifies the destination bitvector of the operation, for inplace operations, specify one of the operands as dst `
include Ops with type with_result := dst:t -> unitTest whether two bitvectors are equal in the positions set in modulo
Creates a fresh bitvector that is the concatenation of v1 and v2.
Return the count of bits set to one.
fold ~init ~f b0...bn is f (f (f init b0)...) bn, where b0...bn are individual bits in a bitvector.
fold_lefti is fold_left with offset provided.
fold over all offsets of set bits.
fold ~init ~f b0...bn is f (f (f init b0)...) bn, where b0...bn are individual bits in a bitvector.
foldi is fold with offset provided.
fold over all offsets of set bits.
mapi ~f b0...bn is f 0 b0 ... f n bn, where bi is i-th bit in a bitvector.
Iterate over all bits and their offsets in reverse order.
Iterate over all offsets of set bits in reverse order.